echo on
rem
rem execNLME.bat : Runs NLME on windows
rem
rem Args :
rem        %1 LCWD       = Full path Working directory to start on local host
rem        %2 MPIFLAG    = MPIYES | MPINO
rem        %3 LOCAL_HOST =  YES | NO
rem        %4 NUM_NODES  = Number of mpi nodes
rem        %5 SHARED_DRIVE = Location of shared drive for remote MPI
rem        %6 RCWD         = Name of the working directory on remote/shared drive
rem        
rem
rem                          This directory will be created on either :
rem                          --  Shared Drive OR
rem                          --  %USERPROFILE%
rem                              on remote nodes and will be cleaned after the
rem                              run is finished.
rem 
rem        %7 FILES_TO_COPY= List of files to copy to remote node or shared directory
rem        %8 NLME_ARGS    = Arguments passed on to xxx.exe
rem 

set WORKING_DIR=%1
set MPIFLAG=%2
set LOCAL_HOST=%3
set NUM_NODES=%4
set SHARED_DRIVE=%5
set RCWD=%6_%RANDOM%
set FILES=%7
set NLME_ARGS=%8

pushd %WORKING_DIR%


echo WORKING_DIR=%WORKING_DIR%,MPIFLAG=%MPIFLAG%, LOCAL_HOST=%LOCAL_HOST%,NUM_NODES=%NUM_NODES%,SHARED_DRIVE=%SHARED_DRIVE%

set EXECUTION_DIR=

rem
rem Are we doing MPI
rem

if %MPIFLAG%==MPINO goto LNoMPI


rem 
rem Do the logic for running on remote nodes here
rem 
if %LOCAL_HOST%==YES goto LLocalHost

rem
rem Figure out what hosts we will be running on
rem

setlocal EnableDelayedExpansion

"%PhoenixMPIDir64%\bin\smpd" -hosts > hostNames
set /a num_hosts=0
for /F %%i IN ( hostNames ) do (
    set /a num_hosts+=1
    set host_names_array[!num_hosts!]=%%i
)

for /L %%i in (1,1,%num_hosts%) do (
    echo !host_names_array[%%i]!
)

rem
rem If we are running on a remote node, we need to copy the needed files over to
rem 
rem Either ) Shared drive
rem OR     ) TEMP directory on the remote hosts
rem

set MAPALLFLAG=-mapall
set EXECUTABLE=.\mpiNLME7.exe
set LOCALONLY=
rem set FILES_TO_COPY=mpiNLME7.exe nlmeargs.txt cols1.txt data1.txt
set FILES_TO_COPY=mpiNLME7.exe %FILES:"=%


if %SHARED_DRIVE%=="" goto LNoSharedDriveCopy

    set EXECUTION_DIR=%SHARED_DRIVE:"=%\%RCWD%
    mkdir %EXECUTION_DIR%
    set EXECUTABLE=%EXECUTION_DIR%\mpiNLME7.exe
    set WD=-wdir %EXECUTION_DIR%     
	set WD=

    for %%x in (%FILES_TO_COPY%) do (
        copy  %%x %EXECUTION_DIR%
    )



goto LRunMPI

:LNoSharedDriveCopy
rem
rem There is no shared drive, we need to copy the files over to a local
rem directory on all remote nodes and then start the run.
rem
set EXECUTION_DIR=%USERPROFILE%\%RCWD%
set EXECUTABLE=%EXECUTION_DIR%\mpiNLME7.exe
set WD=-wdir %EXECUTION_DIR%


    for /L %%i in (1,1,%num_hosts%) do (
rem
rem Check to see if we are handling a  remote node, and do mpicp
rem

        if  /I NOT %COMPUTERNAME% == !host_names_array[%%i]! (
             "%PhoenixMPIDir64%\bin\mpiexec" -n 1 -host !host_names_array[%%i]! cmd /c mkdir %EXECUTION_DIR%
             for %%x in (%FILES_TO_COPY%) do (
                  "%PhoenixMPIDir64%\bin\mpiexec" -n 1 -host %COMPUTERNAME% mpicp.exe send %%x : -n 1 -host !host_names_array[%%i]! mpicp receive %EXECUTION_DIR%\%%x
             )
        )

rem
rem We are on the local hostnode, so just do a local copy
rem
        if  /I %COMPUTERNAME% == !host_names_array[%%i]! (
             mkdir %EXECUTION_DIR%
             for %%x in (%FILES_TO_COPY%) do (
                 copy  %%x %EXECUTION_DIR%
             )
        )

    )

goto LRunMPI


rem
rem local host logic
rem 
:LLocalHost

set WD=
set MAPALLFLAG=
set EXECUTABLE=.\mpiNLME7.exe
set LOCALONLY=-localonly
set EXECUTION_DIR=.\

rem 
rem Run the executable
rem 
:LRunMPI

if %EXECUTION_DIR%==.\ goto LRemovePrefix
SET NLME_ARGS=!NLME_ARGS:EXECUTION_DIR=%EXECUTION_DIR%!
goto LDoneRemovingPrefix
:LRemovePrefix
SET NLME_ARGS=%NLME_ARGS:EXECUTION_DIR\=%
:LDoneRemovingPrefix
echo on
echo "%PhoenixMPIDir64%\bin\mpiexec" -n %NUM_NODES% %WD% %MAPALLFLAG% %LOCALONLY%  %EXECUTABLE% %NLME_ARGS:"=%  > mpilog.txt
echo =====MPI Enabled==== >> mpilog.txt
echo NumNodes    : %NUM_NODES% >> mpilog.txt
echo Local Only  : %LOCALONLY% >> mpilog.txt
echo Shared Dir  : %SHARED_DRIVE% >> mpilog.txt
echo Hosts       : >> mpilog.txt
type hostNames >> mpilog.txt
echo off
"%PhoenixMPIDir64%\bin\mpiexec" -n %NUM_NODES% %WD% %MAPALLFLAG% %LOCALONLY%  %EXECUTABLE% %NLME_ARGS:"=% 1> err1.txt 2> err2.txt



rem
rem If we created a directory to work in, then clean it up.
rem

if %EXECUTION_DIR%==.\ goto LNoCleanup

rem
rem Copy all files from temporary directory to the run directoy
rem
echo %EXECUTION_DIR%
copy %EXECUTION_DIR%\* .



if NOT %SHARED_DRIVE%=="" goto LLocalCleanup
rem
rem Cleanup all directories on remote nodes.
rem
    for /L %%i in (1,1,%num_hosts%) do (
rem
rem Check to see if we are handling a  remote node, and do mpicp
rem
        if  /I NOT %COMPUTERNAME% == !host_names_array[%%i]! (
             "%PhoenixMPIDir64%\bin\mpiexec" -n 1 -host !host_names_array[%%i]! cmd /c del /Q %EXECUTION_DIR%
             "%PhoenixMPIDir64%\bin\mpiexec" -n 1 -host !host_names_array[%%i]! cmd /c rmdir  %EXECUTION_DIR%
        )

        if  /I %COMPUTERNAME% == !host_names_array[%%i]! (
            del /Q %EXECUTION_DIR% 
            rmdir %EXECUTION_DIR%
        )

    )

goto LNoCleanup

rem
rem remove the directory we have created on shared_directory drive
rem
:LLocalCleanup
del /Q %EXECUTION_DIR% 
rmdir %EXECUTION_DIR%


:LNoCleanup

rem

goto LDoneRunning

:LNoMPI
SET NLME_ARGS=%NLME_ARGS:EXECUTION_DIR\=%
echo on
echo ".\NLME7.exe"  %NLME_ARGS:"=%  > mpilog.txt
echo off
".\NLME7.exe"  %NLME_ARGS:"=% 1> err1.txt 2> err2.txt

:LDoneRunning

